pub struct WeakEntityHandle<S> { /* private fields */ }Expand description
A non-owning reference to an entity. Does not keep the entity alive.
When the last EntityHandle for the entity drops, the entity is removed
from the graph and subsequent mutate calls on any WeakEntityHandle
pointing to it become no-ops.
Implementations