pub trait AsEntityRef {
// Required method
fn as_entity_ref(&self) -> EntityRef;
}Expand description
A type that can be used as the on = argument of the moire!() macro.
pub trait AsEntityRef {
// Required method
fn as_entity_ref(&self) -> EntityRef;
}A type that can be used as the on = argument of the moire!() macro.