WeakEntityHandle

Struct WeakEntityHandle 

pub struct WeakEntityHandle<S> { /* private fields */ }
A non-owning reference to an entity. Does not keep the entity alive. When the last EntityHandle for the entity drops, the entity is removed from the graph and subsequent mutate calls on any WeakEntityHandle pointing to it become no-ops.

Implementations

Source

impl<S> WeakEntityHandle<S>
where S: EntityBodySlot,

pub fn rename(&self, name: impl Into<String>) -> bool

pub fn mutate(&self, f: impl FnOnce(&mut S::Value)) -> bool